@@ -1,6 +1,7 @@
 #' Percent Difference
 #'
-#' Convert a vector of values to percent differences.
+#' \code{fv_percent_diff} - Convert a vector of values to percent differences
+#' (i.e., (T2 - T1)/T1).
 #'
 #' @param x A numeric vector.
 #' @param digits The number of digits to use.  Defaults to 1.  Can be set
@@ -42,6 +43,30 @@ fv_percent_diff <- function(x, digits = getOption("numformdigits"), ...){
     f_prop2percent(c(0, (x[-1] - x[-length(x)])/x[-length(x)]), digits = digits, ...)
 }
 
+
+#' \code{fv_percent_diff_fixed_relative} - Similar to \code{fv_percent_diff} but
+#' the comparison year is a constant rather than the prior year.  This is
+#' particularly useful for seeing changes relative to time 1.
+#' @param fixed.relative The position of the element to be used for comparison.
+#' Default is the first element.
+#' @export
+#' @include utils.R
+#' @rdname fv_percent_diff
+fv_percent_diff_fixed_relative <- function(x, fixed.relative = 1, digits = getOption("numformdigits"), ...){
+    f_prop2percent(c(0, x[-1] - x[fixed.relative])/x[fixed.relative], digits = digits, ...)
+}
+
+
+
+
+#' @export
+#' @include utils.R
+#' @rdname fv_percent_diff
+ffv_percent_diff_fixed_relative <- functionize(fv_percent_diff_fixed_relative)
+
+
+
+
 #' @export
 #' @include utils.R
 #' @rdname fv_percent_diff
